@@ -1,4 +1,4 @@
-# @(#)Ident: CPANTesting.pm 2013-08-01 11:23 pjf ;
+# @(#)Ident: CPANTesting.pm 2013-08-06 15:43 pjf ;
 
 package CPANTesting;
 
@@ -20,14 +20,14 @@ sub should_abort {
 }
 
 sub test_exceptions {
-   my $p = shift; my $perl_ver = $p->{requires}->{perl};
+   my $p = shift; my $perl_ver = $p->{_min_perl_ver} || $p->{requires}->{perl};
 
-   is_testing()          or  return 0;
-   $] < $perl_ver        and return "TESTS: Perl minimum ${perl_ver}";
-   $p->{stop_tests}      and return 'TESTS: CPAN Testing stopped in Build.PL';
-   $osname eq q(mirbsd)  and return 'TESTS: Mirbsd OS unsupported';
-   $host   eq q(slack64) and return 'tests: No space left on device';
-   $host   eq q(falco)   and return 'tests: No space left on device';
+   is_testing()         or  return 0;
+   $] < $perl_ver       and return "TESTS: Perl minimum ${perl_ver}";
+   $p->{stop_tests}     and return 'TESTS: CPAN Testing stopped in Build.PL';
+   $osname eq 'mirbsd'  and return 'TESTS: Mirbsd OS unsupported';
+   $host   eq 'slack64' and return 'tests: No space left on device';
+   $host   eq 'falco'   and return 'tests: No space left on device';
    return 0;
 }
 
